#if defined _revive_teammates_included
  #endinput
#endif
#define _revive_teammates_included

#include <revive_teammates_const>

#if AMXX_VERSION_NUM >= 175
	#pragma reqlib revive_teammates
	#if !defined AMXMODX_NOAUTOLOAD
		#pragma loadlib revive_teammates
	#endif
#else
	#pragma library revive_teammates
#endif

/**
 * Retrives a plugin prefix
 *
 * @param string        String buffer to copy 
 * @param len           Max buffer size
 *
 * @noreturn
 */
native RT_GetPrefix(string[], len);

/**
 * Force delete a player corpse
 * 
 * @param id            Player index
 * 
 * @return              true if the deletion was successful, false otherwise
 */
native RT_DeleteCorpse(id);

/**
 * Get a entity index of player corpse
 * 
 * @param id            Player index
 * 
 * @return              Entity index of player corpse, 0 otherwise (player alive or switching team, etc..)
 */
native RT_GetCorpse(const id);

/**
 * Checks if the player is using a corpse right now
 * 
 * @param id            Player index
 * 
 * @return              true if using, false otherwise
 */
native bool:RT_IsUsing(const id);

/**
 * Check if an action with this status is possible
 * 
 * @param status        Relation status (see revive_teammates_const.inc)
 * 
 * @return              true on success, false otherwise
 */
native bool:RT_Get_Relation(RelationStatus:status);

/**
 * Establish interaction with this status
 * 
 * @param status        Relation status (see revive_teammates_const.inc)
 * @param set           Interaction control
 * 
 * @noreturn
 */
native RT_Set_Relation(RelationStatus:status, bool:set);

/**
 * Get a relationship status between two players
 * 
 * @param player        Player index (like a victim)
 * @param target        Player index (like a attacker)
 * 
 * @return              Relation status (see revive_teammates_const.inc)
 */
native RelationStatus:RT_RelationShipStatus(const player, const target);

/**
 * Force's a begin action of revive
 * 
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param skip_checks   If true, the process cannot be stopped by other plugins.
 *                      Be carefully about plugin logic
 * 
 * @return              true on success, false otherwise
 */
native RT_GoAction(const corpse_id, const activator, const bool:skip_checks = false);

/**
 * Instantly a break action of revive
 * 
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param owner         Player index (owner of corpse)
 * @param complete      Complete status
 * 
 * @return              true on success, false otherwise
 */
native RT_BreakAction(const corpse_id, const activator, const owner, bool:complete);

/**
 * Called when player cathed corpse via button (on +use)
 *
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param owner         Player index (owner of corpse)
 *
 * @return      RT_CONTIUE to let the activator use the corpse
 *              RT_SUPERCEDE to prevent this action
 */
forward RT_StartLoot_Pre(const corpse_id, const activator, const owner);

/**
 * Called when player cathed corpse via button (on USE)
 *
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param owner         Player index (owner of corpse)
 * @param duration      Time for the process
 *
 * @noreturn
 */
forward RT_StartLoot_Post(const corpse_id, const activator, const owner, Float:duration);

/**
 * Called when the player has finished reviving or disactivate it.
 *
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param owner         Player index (owner of corpse)
 * @param complete      This means the revive is passed
 *
 * @return     RT_CONTINUE to let the completed it successfully and the player will be spawned
 *             RT_SUPERCEDE or higher complete the process, but the player will not be revived
 */
forward RT_StopLoot(const corpse_id, const activator, const owner, bool:complete);

/**
 * Called when creating the corpse of a deceased player (ClCorpse message)
 *
 * @param corpse_id     Entity index of corpse
 * @param owner         Player index (owner of corpse)
 *
 * @return     CORPSE_CUSTOM a custom corpse with defined properties (using by default)
 *             CORPSE_DEFAULT a corpse is created via a message (default behaviour)
 *             CORPSE_BLOCK prevent the appearance of a corpse 
 */
forward RT_StartSneaking(const corpse_id, const owner, const Float:origin[3]);

/**
 * Called when the corpse is removed (when spawning, changing the team, exiting the server, etc..)
 *
 * @param corpse_id     Entity index of corpse
 * @param owner     	Player index (owner of corpse)
 *
 * @noreturn
 */
forward RT_StopSneaking(const corpse_id, const owner);

/**
 * Called at every think of entity
 *
 * @param corpse_id     Entity index of corpse
 * @param activator     Player index (corpse activator)
 * @param owner     	Player index (owner of corpse)
 * @param time_ending   This is the time when the process of rebirth will be completed
 * @param nextthink     This is the time of the next call (can be overwritten) [def: 1.0]
 *
 * @return     RT_CONTINUE to let the continue of procces
 *             RT_SUPERCEDE or higher to prevent this action
 */
forward RT_ThinkLoot(const corpse_id, const activator, const owner, Float:time_ending, &nextthink);

/**
 * Called immediately after the resurrection of the player
 *
 * @param id            Player index (who was reborn)
 * @param friend        Player index by which the player was resurrected
 *
 * @noreturn
 */
forward RT_GotRespawn(const id, const friend);

/**
 * Called when config file is parsing..
 *
 * @param jsonMain      JSON Handle
 *
 * @note This must called only in plugin_precache() forward.
 *
 * @noreturn
 */
forward RT_ParseConfigFile(JSON:jsonMain);